import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { ActionSheet } from '..';
import toJson from 'enzyme-to-json';
import { sleep } from '../../../tests/utils';
describe('Popup', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  test('should emit select event after clicking option', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var actions, onSelect;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            // const wrapper = mount(ActionSheet, {
            //     props: {
            //         show: true,
            //         actions: [{ name: 'Option' }],
            //     },
            // });
            actions = [{
              name: 'Option'
            }];
            onSelect = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
              visible: true,
              actions: actions,
              onSelect: onSelect
            }));
            wrapper.find('.rc-action-sheet__item').simulate('click');
            _context.next = 6;
            return sleep(0);

          case 6:
            expect(onSelect).toHaveBeenCalledTimes(1);
            expect(onSelect).toHaveBeenCalledWith({
              name: 'Option'
            }, 0);

          case 8:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  test('should call callback function after clicking option', function () {
    var callback = jest.fn();
    var actions = [{
      name: 'Option',
      callback: callback
    }];
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      actions: actions
    }));
    wrapper.find('.rc-action-sheet__item').simulate('click');
    expect(callback).toHaveBeenCalledTimes(1);
  });
  test('should not emit select event after clicking loading option', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var onSelect, actions;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onSelect = jest.fn();
            actions = [{
              name: 'Option',
              loading: true
            }];
            wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
              visible: true,
              actions: actions,
              onSelect: onSelect
            }));
            wrapper.find('.rc-action-sheet__item').simulate('click');
            _context2.next = 6;
            return sleep(0);

          case 6:
            expect(onSelect).not.toHaveBeenCalled();

          case 7:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  test('should not emit select event after clicking disabled option', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var onSelect, actions;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            onSelect = jest.fn();
            actions = [{
              name: 'Option',
              disabled: true
            }];
            wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
              visible: true,
              actions: actions,
              onSelect: onSelect
            }));
            wrapper.find('.rc-action-sheet__item').simulate('click');
            _context3.next = 6;
            return sleep(0);

          case 6:
            expect(onSelect).not.toHaveBeenCalled();

          case 7:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  test('should emit cancel event after clicking cancel button', function () {
    var onCancel = jest.fn();
    var actions = [{
      name: 'Option'
    }];
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      actions: actions,
      cancelText: "Cancel",
      onCancel: onCancel
    }));
    wrapper.find('.rc-action-sheet__cancel').simulate('click');
    expect(onCancel).toHaveBeenCalledTimes(1);
  });
  test('should render subname correctly', function () {
    var actions = [{
      name: 'Option',
      subname: 'Subname'
    }];
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      actions: actions,
      cancelText: "Cancel"
    }));
    expect(wrapper.find('.rc-action-sheet__subname').text()).toEqual('Subname');
    expect(wrapper.find('.rc-action-sheet__item').html()).toMatchSnapshot();
  });
  test('should render default slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      title: "Title"
    }, "Default"));
    expect(wrapper.html()).toMatchSnapshot();
  });
  test('should have "van-popup--round" class when setting the round prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      round: true
    }));
    expect(wrapper.find('.rc-popup--round').exists()).toBeTruthy();
  });
  test('should change option color when using the color prop', function () {
    var actions = [{
      name: 'Option',
      color: 'red'
    }];
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      actions: actions
    }));
    var item = wrapper.find('.rc-action-sheet__item');
    expect(item.getDOMNode().style.color).toEqual('red');
  });
  test('should hide close icon when the closeable prop is false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
              visible: true,
              title: "Title"
            }));
            expect(wrapper.find('.rc-action-sheet__close').exists()).toBeTruthy();
            _context4.next = 4;
            return wrapper.setProps({
              closeable: false
            });

          case 4:
            expect(wrapper.find('.rc-action-sheet__close').exists()).toBeFalsy();

          case 5:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  test('should allow to custom close icon with closeIcon prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      title: "Title",
      closeIcon: "success"
    }));
    expect(toJson(wrapper.find('.rc-action-sheet__close'))).toMatchSnapshot();
  });
  test('should render description correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      description: "This is a description"
    }));
    expect(wrapper.find('.rc-action-sheet__description').text()).toEqual('This is a description');
    expect(toJson(wrapper.find('.rc-action-sheet__description'))).toMatchSnapshot();
  }); // test('should close after clicking option if close-on-click-action prop is true', () => {
  //     const actions = [{ name: 'Option' }];
  //     wrapper = mount(<ActionSheet visible closeOnClickAction actions={actions} />);
  //     wrapper.find('.rc-action-sheet__item').simulate('click');
  //     console.log("============", wrapper.find(".rc-action-sheet").at(1).html());
  //     expect(wrapper.find(".rc-action-sheet").at(1).getDOMNode().style.display).toEqual("none");
  // });

  test('should emit click-overlay event and closed after clicking the overlay', function () {
    var onClickOverlay = jest.fn();
    var actions = [{
      name: 'Option'
    }];
    wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
      visible: true,
      onClickOverlay: onClickOverlay,
      actions: actions
    }));
    wrapper.find('.rc-overlay').simulate('click'); // expect(wrapper.emitted('update:show')![0]).toEqual([false]);

    expect(onClickOverlay).toHaveBeenCalledTimes(1);
  });
  test('should allow to control safe-area with safe-area-inset-bottom prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(ActionSheet, {
              visible: true
            }));
            expect(wrapper.find('.rc-action-sheet').at(1).hasClass('rc-safe-area-bottom')).toBeTruthy();
            _context5.next = 4;
            return wrapper.setProps({
              safeAreaInsetBottom: false
            });

          case 4:
            expect(wrapper.find('.rc-action-sheet').at(1).hasClass('rc-safe-area-bottom')).toBeFalsy();

          case 5:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
});