import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import Cell from '..';
describe('Cell', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should render value slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      value: "Custom Value"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render title slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Custom Title"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render label slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      label: "Custom Label"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render icon slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      icon: "location-o"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render extra slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      value: "Value",
      extra: "Custom Extra"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should change arrow direction when using arrow-direction prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      value: "Value",
      isLink: true,
      arrowDirection: "down"
    }));
    expect(wrapper.find('.rc-cell__right-icon').exists()).toBeTruthy();
    expect(wrapper.find('.van-icon-arrow-down').exists()).toBeTruthy();
  });
  it('should change title style when using title-style prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      titleStyle: {
        color: 'red'
      }
    }));
    var title = wrapper.find('.rc-cell__title');
    expect(title.getDOMNode().style.color).toEqual('red');
  });
  it('should change icon class prefix when using icon-prefix prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      icon: "success",
      iconPrefix: "my-icon"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should allow to disable clicakble when using is-link prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell, {
      title: "Title",
      isLink: true,
      clickable: false
    }));
    expect(wrapper.find('.rc-cell--clickable').exists()).toBeTruthy();
  });
  it('should render correctly when wrapperd with Cell.Group', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell.Group, null, /*#__PURE__*/React.createElement(Cell, {
      title: "\u5355\u5143\u683C",
      value: "\u5185\u5BB9"
    }), /*#__PURE__*/React.createElement(Cell, {
      title: "\u5355\u5143\u683C",
      value: "\u5185\u5BB9",
      label: "\u63CF\u8FF0\u4FE1\u606F"
    })));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render correctly when using title prop in Cell.Group', function () {
    wrapper = mount( /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Cell.Group, {
      title: "\u5206\u7EC41"
    }, /*#__PURE__*/React.createElement(Cell, {
      title: "\u5355\u5143\u683C",
      value: "\u5185\u5BB9"
    })), /*#__PURE__*/React.createElement(Cell.Group, {
      title: "\u5206\u7EC42"
    }, /*#__PURE__*/React.createElement(Cell, {
      title: "\u5355\u5143\u683C",
      value: "\u5185\u5BB9"
    }))));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render correctly when using inset prop in Cell.Group', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cell.Group, {
      inset: true
    }, /*#__PURE__*/React.createElement(Cell, {
      title: "\u5355\u5143\u683C",
      value: "\u5185\u5BB9"
    }), /*#__PURE__*/React.createElement(Cell, {
      title: "\u5355\u5143\u683C",
      value: "\u5185\u5BB9",
      label: "\u63CF\u8FF0\u4FE1\u606F"
    })));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
});