import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount, shallow } from 'enzyme';
import toJson from 'enzyme-to-json';
import Dialog from '..';
import Button from '../../button';
describe('Dialog', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.clearAllMocks();
  });
  it('should change confirm button color when using confirm-button-color prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
      visible: true,
      confirmButtonColor: "red"
    }));
    var confirmButton = wrapper.find('.rc-dialog__confirm').at(0);
    expect(confirmButton.getDOMNode().style.color).toEqual('red');
  });
  it('should change cancel button color when using cancel-button-color prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
      visible: true,
      showCancelButton: true,
      cancelButtonColor: "red"
    }));
    var cancelButton = wrapper.find('.rc-dialog__cancel').at(0);
    expect(cancelButton.getDOMNode().style.color).toEqual('red');
  });
  it('should render button text correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
      visible: true,
      showCancelButton: true,
      cancelButtonText: "Custom Cancel",
      confirmButtonText: "Custom Confirm"
    }));
    expect(wrapper.find('.rc-dialog__footer').html()).toMatchSnapshot();
  });
  it('should render default slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
      visible: true,
      message: "Custom Message"
    }));
    expect(wrapper.find('.rc-dialog__message').text()).toEqual('Custom Message');
    expect(wrapper.find('.rc-dialog__content').html()).toMatchSnapshot();
  });
  it('should render title slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
      visible: true,
      title: "Custom Title"
    }));
    expect(wrapper.find('.rc-dialog__header').text()).toEqual('Custom Title');
    expect(toJson(wrapper.find('.rc-dialog__header'))).toMatchSnapshot();
  });
  it('should emit open event when show prop is set to true', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onOpen;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onOpen = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
              onOpen: onOpen
            }));
            _context.next = 4;
            return wrapper.setProps({
              visible: true
            });

          case 4:
            expect(onOpen).toHaveBeenCalledTimes(1);

          case 5:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should emit close event when show prop is set to false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var onClose, onClickCloseIcon;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onClose = jest.fn();
            onClickCloseIcon = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
              onClose: onClose,
              closeable: true,
              onClickCloseIcon: onClickCloseIcon
            }));
            wrapper.setProps({
              visible: true
            });
            wrapper.find('i').simulate('click');
            wrapper.setProps({
              visible: false
            });
            expect(onClose).toHaveBeenCalledTimes(1);

          case 7:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should update width when using width prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
              visible: true,
              width: 200
            }));
            expect(wrapper.find('.rc-dialog').at(1).getDOMNode().style.width).toEqual('200px');

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render footer correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
      visible: true,
      message: "message",
      footer: /*#__PURE__*/React.createElement(Button, null, "Footer")
    }));
    expect(wrapper.find('.rc-dialog').at(1).find('.rc-button__text').text()).toEqual('Footer');
  });
  it('should correctly when showCancelButton prop is true', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Dialog, {
      visible: true,
      message: "message",
      showCancelButton: true
    }));
    expect(wrapper.find('.rc-dialog').at(1).find('.rc-dialog__cancel').find('.rc-button__text').text()).toEqual('取消');
  });
  it('should correctly when theme prop is round-button', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Dialog, {
      visible: true,
      message: "message",
      theme: "round-button",
      showCancelButton: true
    }));
    expect(wrapper.find('.rc-dialog__footer').find('ActionBarButton')).toHaveLength(2);
  });
});