import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { sleep } from '../../../tests/utils';
import Icon from '../../icon';
import { Field } from '..';
describe('Field', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.clearAllMocks();
  });
  it('should update value when after inputting', function () {
    var onChange = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      onChange: onChange
    }));
    var mockedEvent = {
      preventDefault: jest.fn(),
      target: {
        value: 'world'
      }
    };
    wrapper.find('input').simulate('change', mockedEvent);
    wrapper.update();
    expect(onChange).toHaveBeenCalledWith('world');
  });
  it('should emit onClickInput event when input is clicked', function () {
    var onClickInput = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      onClickInput: onClickInput
    }));
    wrapper.find('input').simulate('click');
    expect(onClickInput).toHaveBeenCalled();
  });
  it('should emit click-input event when using input slot', function () {
    var onClickInput = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      onClickInput: onClickInput
    }, /*#__PURE__*/React.createElement("input", null)));
    wrapper.find('.rc-field__control').simulate('click');
    expect(onClickInput).toHaveBeenCalled();
  });
  it('should onClickLeftIcon event when left icon is clicked', function () {
    var onClickLeftIcon = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      leftIcon: "contact",
      onClickLeftIcon: onClickLeftIcon,
      iconPrefix: "my-icon"
    }));
    wrapper.find('.rc-field__left-icon').simulate('click');
    expect(onClickLeftIcon).toHaveBeenCalled();
  });
  it('should emit onClickRightIcon event when right icon is clicked', function () {
    var onClickRightIcon = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      rightIcon: "search",
      onClickRightIcon: onClickRightIcon
    }));
    wrapper.find('.rc-field__right-icon').simulate('click');
    expect(onClickRightIcon).toHaveBeenCalled();
  });
  it('should format input value when type is number', function () {
    var onChange = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "number",
      onChange: onChange
    }));
    var input = wrapper.find('input');
    input.simulate('change', {
      preventDefault: jest.fn(),
      target: {
        value: '1'
      }
    });
    expect(onChange).toHaveBeenCalledWith('1');
    input.simulate('change', {
      preventDefault: jest.fn(),
      target: {
        value: '2'
      }
    });
    expect(onChange).toHaveBeenCalledWith('2');
    input.simulate('change', {
      preventDefault: jest.fn(),
      target: {
        value: '123abc'
      }
    });
    expect(onChange).toHaveBeenCalledWith('123');
  });
  it('should format input value when type is digit', function () {
    var onChange = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "digit",
      value: "",
      onChange: onChange
    }));
    var input = wrapper.find('input');
    input.simulate('change', {
      preventDefault: jest.fn(),
      target: {
        value: '1'
      }
    });
    expect(onChange).toHaveBeenCalledWith('1');
    input.simulate('change', {
      preventDefault: jest.fn(),
      target: {
        value: '2'
      }
    });
    expect(onChange).toHaveBeenCalledWith('2');
    input.simulate('change', {
      preventDefault: jest.fn(),
      target: {
        value: '123abc'
      }
    });
    expect(onChange).toHaveBeenCalledWith('123');
  });
  it('should render textarea when type is textarea', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "textarea",
              autosize: true
            }));
            _context.next = 3;
            return sleep(0);

          case 3:
            expect(toJson(wrapper)).toMatchSnapshot();

          case 4:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should autosize textarea field', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var value, textarea;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "textarea",
              autosize: true
            }));
            value = '1'.repeat(20);
            textarea = wrapper.find('.rc-field__control');
            _context2.next = 5;
            return wrapper.setProps({
              value: value
            });

          case 5:
            expect(textarea.text()).toEqual(value);

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should allow autosize prop be be an object', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var autosize, textarea;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            window.scrollTo = jest.fn();
            autosize = {
              maxHeight: 100,
              minHeight: 50
            };
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "textarea",
              autosize: autosize
            }));
            textarea = wrapper.find('.rc-field__control');
            _context3.next = 6;
            return sleep(0);

          case 6:
            expect(textarea.getDOMNode().style.height).toEqual('50px');

          case 7:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should onFocus call correctly', function () {
    var onFocus = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      onFocus: onFocus
    }));
    wrapper.find('input').simulate('focus');
    expect(onFocus).toHaveBeenCalled();
  });
  it('should onBlur called correctly', function () {
    var onBlur = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      onBlur: onBlur
    }));
    wrapper.find('input').simulate('blur');
    expect(onBlur).toHaveBeenCalled();
  });
  it('should limit maxlength of input value when using maxlength prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var onChange, input;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "number",
              maxlength: 3,
              value: "1234",
              onChange: onChange
            }));
            input = wrapper.find('input');
            _context4.next = 5;
            return input.simulate('change');

          case 5:
            expect(onChange).toHaveBeenCalledWith('123');

          case 6:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render clear icon when using clearable prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    var onFocus, input;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            onFocus = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              clearable: true,
              type: "text",
              value: "test",
              onFocus: onFocus
            }));
            expect(wrapper.find('.rc-field__clear').exists()).toBeFalsy();
            input = wrapper.find('input');
            _context5.next = 6;
            return input.simulate('focus');

          case 6:
            expect(wrapper.find('.rc-field__clear').exists()).toBeTruthy();

          case 7:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should always render clear icon when clear-trigger prop is always', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              clearable: true,
              type: "text",
              value: "test"
            }));
            expect(wrapper.find('.rc-field__clear').exists()).toBeFalsy();
            wrapper.setProps({
              clearTrigger: 'always'
            });
            expect(wrapper.find('.rc-field__clear').exists()).toBeTruthy();

          case 4:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render extra slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: "test",
      extra: /*#__PURE__*/React.createElement(Icon, {
        name: "success"
      })
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should change cell size when using size prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: "test",
      size: "large"
    }));
    expect(wrapper.find('.rc-cell--large').exists()).toBeTruthy();
  });
  it('should render label slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: "test",
      label: "Lable"
    }));
    expect(toJson(wrapper.find('.rc-field__label'))).toMatchSnapshot();
  });
  it('should allow to set label width with unit', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: "test",
      label: "Lable",
      labelWidth: "10rem"
    }));
    var label = wrapper.find('.rc-field__label');
    expect(label.getDOMNode().style.width).toEqual('10rem');
  });
  it('should allow to set label width without unit', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: "test",
      label: "Lable",
      labelWidth: 100
    }));
    var label = wrapper.find('.rc-field__label');
    expect(label.getDOMNode().style.width).toEqual('100px');
  });
  it('should render label class name when using labelClass prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: "test",
      label: "Lable",
      labelClass: "custom-class"
    }));
    expect(wrapper.find('.rc-field__label').hasClass('custom-class')).toBeTruthy();
  });
  it('should change arrow direction when using arrow-direction prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: "test",
      isLink: true,
      arrowDirection: "up"
    }));
    expect(wrapper.find('.van-icon-arrow-up').exists()).toBeTruthy();
  });
  it('should allow to format value with formatter prop', function () {
    var onChange = jest.fn();

    var formatter = function formatter(value) {
      return value.replace(/\d/g, '');
    };

    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      formatter: formatter,
      onChange: onChange
    }));
    wrapper.find('input').simulate('change', {
      preventDefault: jest.fn(),
      target: {
        value: 'abc123'
      }
    }); // expect(onChange).toHaveBeenCalledWith("abc") 功能同下;

    expect(onChange.mock.calls[0][0]).toEqual('abc');
  });
  it('should trigger format after blurring when format-trigger prop is blur', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    var onChange, formatter;
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            onChange = jest.fn();

            formatter = function formatter(value) {
              return value.replace(/\d/g, '');
            };

            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "text",
              value: "abc123",
              formatter: formatter,
              formatTrigger: "onBlur",
              onChange: onChange
            }));
            wrapper.find('input').simulate('change', {
              preventDefault: jest.fn(),
              target: {
                value: '123efg'
              }
            });
            expect(onChange.mock.calls[0][0]).toEqual('123efg');
            _context7.next = 7;
            return wrapper.setProps({
              value: '123efg'
            });

          case 7:
            wrapper.find('input').simulate('focus');
            wrapper.find('input').simulate('blur');
            expect(onChange).toHaveBeenCalledWith('efg');

          case 10:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render word limit correctly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    var onChange;
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "textarea",
              maxlength: 3,
              showWordLimit: true,
              onChange: onChange
            }));
            wrapper.find('textarea').simulate('change', {
              target: {
                value: 'world'
              }
            });
            expect(onChange).toHaveBeenCalledWith('wor');
            expect(toJson(wrapper)).toMatchSnapshot();

          case 5:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render word limit correctly when value is undefined', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: undefined,
      maxlength: 3,
      showWordLimit: true
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render input name when using name prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      name: "world"
    }));
    expect(wrapper.find('input').props().name).toEqual('world');
  });
  it('should render colon when using colon prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      label: "world",
      colon: true
    }));
    expect(wrapper.find('.rc-field__label').text()).toEqual('world:');
    expect(toJson(wrapper.find('.rc-field__label'))).toMatchSnapshot();
  });
  it('should blur search input after pressing enter', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    var onKeypress, inputRef;
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            onKeypress = jest.fn();
            inputRef = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              getInputRef: inputRef,
              type: "search",
              onKeypress: onKeypress
            }));
            _context9.next = 5;
            return wrapper.find('input').simulate('keypress');

          case 5:
            expect(onKeypress).toHaveBeenCalledTimes(1);

          case 6:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('should format value after mounted if initial value is null', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Field, {
      type: "text",
      value: ""
    }));
    expect(wrapper.find('input').props().value).toEqual('');
  });
  it('should change clear icon when using clear-icon prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
    var onFocus, input;
    return _regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            onFocus = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "text",
              clearIcon: "cross",
              clearable: true,
              value: "test",
              onFocus: onFocus
            }));
            input = wrapper.find('input');
            _context10.next = 5;
            return input.simulate('focus');

          case 5:
            expect(onFocus).toHaveBeenCalled();
            expect(toJson(wrapper.find('.rc-field__clear'))).toMatchSnapshot();

          case 7:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('should render correctly when error prop is set', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
    return _regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "text",
              placeholder: "\u8BF7\u8F93\u5165\u7528\u6237\u540D",
              error: true
            }));
            expect(wrapper.find('.rc-field__control--error').exists()).toBeTruthy();

          case 2:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
  it('should render error-message slot correctly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee12() {
    return _regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "text",
              errorMessage: "this is an error message"
            }));
            expect(wrapper.find('.rc-field__error-message').text()).toEqual('this is an error message');
            expect(toJson(wrapper.find('.rc-field__error-message'))).toMatchSnapshot();

          case 3:
          case "end":
            return _context12.stop();
        }
      }
    }, _callee12);
  })));
  it('should render correctly when tooltip is not vaildElement or string ', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee13() {
    var tooltip, dialogMessage;
    return _regeneratorRuntime.wrap(function _callee13$(_context13) {
      while (1) {
        switch (_context13.prev = _context13.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "text",
              label: "label",
              tooltip: {
                message: 'world'
              }
            }));
            tooltip = wrapper.find('.rc-field__tooltip');
            _context13.next = 4;
            return tooltip.simulate('click');

          case 4:
            dialogMessage = global.document.body.querySelector('.rc-dialog__message');
            expect(dialogMessage.textContent).toEqual('world');

          case 6:
          case "end":
            return _context13.stop();
        }
      }
    }, _callee13);
  })));
  it('should emit onClear event correctly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee14() {
    var onChange, onClear;
    return _regeneratorRuntime.wrap(function _callee14$(_context14) {
      while (1) {
        switch (_context14.prev = _context14.next) {
          case 0:
            onChange = jest.fn();
            onClear = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "text",
              label: "label",
              value: "abc",
              clearable: true,
              onClear: onClear,
              onChange: onChange
            }));
            _context14.next = 5;
            return wrapper.find('input').simulate('focus');

          case 5:
            wrapper.find(Icon).simulate('touchstart');
            expect(onChange).toHaveBeenCalled();
            expect(onClear).toHaveBeenCalled();

          case 8:
          case "end":
            return _context14.stop();
        }
      }
    }, _callee14);
  })));
  it('should render intro correctly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee15() {
    return _regeneratorRuntime.wrap(function _callee15$(_context15) {
      while (1) {
        switch (_context15.prev = _context15.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "text",
              label: "label",
              value: "abc",
              intro: /*#__PURE__*/React.createElement(Icon, {
                name: "shop-o"
              })
            }));
            expect(wrapper.find('i').hasClass('van-icon-shop-o')).toBeTruthy();

          case 2:
          case "end":
            return _context15.stop();
        }
      }
    }, _callee15);
  })));
  it('should render correctly when readonly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee16() {
    return _regeneratorRuntime.wrap(function _callee16$(_context16) {
      while (1) {
        switch (_context16.prev = _context16.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Field, {
              type: "text",
              label: "label",
              value: "abc",
              readonly: true
            }));
            wrapper.find('input').simulate('focus');

          case 2:
          case "end":
            return _context16.stop();
        }
      }
    }, _callee16);
  })));
});