import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { Icon } from '..';
var IconFont = Icon.createFromIconfontCN('//at.alicdn.com/t/font_2763890_w471tfudy4d.js');
describe('Icon', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should render icon with builtin icon name correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Icon, {
      name: "success"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should render icon with url name correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Icon, {
      name: "https://img.yzcdn.com/icon.jpg"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should render default slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Icon, {
      name: "success"
    }, "Default Slot"));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should change root tag after using tag prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Icon, {
      name: "success",
      tag: "div"
    }, "Default Slot"));
    expect(wrapper.html()).toEqual('<div class="rc-badge__wrapper van-icon van-icon-success">Default Slot</div>');
  });
  it('should render dot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Icon, {
      name: "success",
      dot: true
    }));
    expect(wrapper.find('.rc-badge').html()).toMatchSnapshot();
  });
  it('should render badge correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Icon, {
      name: "success",
      badge: {
        content: 9
      }
    }));
    expect(wrapper.find('.rc-badge').html()).toMatchSnapshot();
  });
  it('should change icon size when using size prop', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Icon, {
      name: "success",
      size: 20
    }));
    expect(wrapper.getDOMNode().style.fontSize).toEqual('20px');
  });
  it('should render correctly when createFromIconfontCN', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(IconFont, {
      name: "cuIcon-classify",
      color: "#f44336"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
});