import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import * as React from 'react';
import { mount } from 'enzyme';
import { fireEvent, render } from '@testing-library/react';
import '@testing-library/jest-dom/extend-expect';
import Image from '..';
var IMAGE_URL = 'https://img.com';
describe('Image', function () {
  afterEach(function () {
    jest.restoreAllMocks();
  });
  it('should emit load event after image loaded', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onLoad, wrapper;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onLoad = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Image, {
              src: IMAGE_URL,
              onLoad: onLoad
            }));
            _context.next = 4;
            return wrapper.find('img').simulate('load');

          case 4:
            expect(onLoad).toHaveBeenCalled();
            expect(wrapper.html()).toMatchSnapshot();

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should watch src and reset', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var wrapper;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Image, {
              src: IMAGE_URL
            }));
            _context2.next = 3;
            return wrapper.find('img').simulate('load');

          case 3:
            _context2.next = 5;
            return wrapper.setProps({
              src: ''
            });

          case 5:
            expect(wrapper.html()).toMatchSnapshot();

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should emit error event when load image failed', function () {
    var onError = jest.fn();

    var _render = render( /*#__PURE__*/React.createElement(Image, {
      alt: "errJpg",
      src: IMAGE_URL,
      onError: onError
    })),
        getByAltText = _render.getByAltText;

    fireEvent.error(getByAltText('errJpg'));
    expect(onError).toHaveBeenCalled();
  });
  it('should not render loading placeholder when show-loading prop is false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var wrapper;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Image, null));
            expect(wrapper.find('.rc-image__loading').exists()).toBeTruthy();
            _context3.next = 4;
            return wrapper.setProps({
              showLoading: false
            });

          case 4:
            expect(wrapper.find('.rc-image__loading').exists()).toBeFalsy();

          case 5:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should not render error placeholder when show-error prop is false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var _render2, getByAltText, container;

    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _render2 = render( /*#__PURE__*/React.createElement(Image, {
              src: IMAGE_URL,
              alt: "test",
              showError: false
            })), getByAltText = _render2.getByAltText, container = _render2.container;
            fireEvent.error(getByAltText('test'));
            expect(container.querySelector('.rc-image__error')).not.toBeInTheDocument();

          case 3:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should change loading icon when using loading-icon prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Image, {
      loadingIcon: "success"
    }));
    expect(wrapper.find('.van-icon-success').exists()).toBeTruthy();
  });
  it('should render correctly when using width and height prop', function () {
    var _render3 = render( /*#__PURE__*/React.createElement(Image, {
      width: 100,
      height: 100
    })),
        container = _render3.container;

    expect(container.querySelector('.rc-image').getAttribute('style')).toEqual('width: 100px; height: 100px;');
  });
  it('should render correctly when using radius prop', function () {
    var _render4 = render( /*#__PURE__*/React.createElement(Image, {
      width: 100,
      height: 100,
      radius: 10
    })),
        container = _render4.container;

    expect(container.querySelector('.rc-image')).toHaveStyle('border-radius: 10px');
  });
});