import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { shallow, mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { mockRect } from '../../utils/dom/mock';
import Slider from '..';
describe('Slider', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('shallows correctly', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, null));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('min', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      min: 0
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('max', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      max: 100
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('step', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      step: 5
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('vertical', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      vertical: true
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('barHeight', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      barHeight: 2
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('buttonSize', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      buttonSize: 20
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('activeColor', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      activeColor: "#ee0a24"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('inactiveColor', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      activeColor: "#e9e9e9"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('button', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      button: /*#__PURE__*/React.createElement("div", {
        className: "custom-button"
      }, "button")
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('button is function', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      button: function button(_ref) {
        var value = _ref.value;
        return /*#__PURE__*/React.createElement("div", {
          className: "custom-button"
        }, value);
      },
      value: 0
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render left button and right button correctly under rang mode', function () {
    wrapper = shallow( /*#__PURE__*/React.createElement(Slider, {
      range: true,
      leftButton: /*#__PURE__*/React.createElement("div", {
        className: "custom-button"
      }, "leftButton"),
      rightButton: /*#__PURE__*/React.createElement("div", {
        className: "custom-button"
      }, "rightButton"),
      value: [20, 80]
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  test('should emit change event under rang mode', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onChange, touchStartEvent, touchMoveEvent, button;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            mockRect(false);
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onChange: onChange,
              value: [20, 80],
              range: true
            }));
            touchStartEvent = {
              touches: [{
                clientX: 0,
                clientY: 0
              }]
            };
            touchMoveEvent = {
              touches: [{
                clientX: 20,
                clientY: 0
              }]
            };
            button = wrapper.find('[role="slider"]').at(0);
            _context.next = 8;
            return button.invoke('onTouchStart')(touchStartEvent);

          case 8:
            _context.next = 10;
            return button.invoke('onTouchMove')(touchMoveEvent);

          case 10:
            expect(onChange).toHaveBeenCalledWith([40, 80]);

          case 11:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  test('should emit change event after dragging button', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var onChange, touchStartEvent, touchMoveEvent, button;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            mockRect(false);
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onChange: onChange,
              value: 0
            }));
            touchStartEvent = {
              touches: [{
                clientX: 0,
                clientY: 0
              }]
            };
            touchMoveEvent = {
              touches: [{
                clientX: 20,
                clientY: 0
              }]
            };
            button = wrapper.find('[role="slider"]');
            _context2.next = 8;
            return button.invoke('onTouchStart')(touchStartEvent);

          case 8:
            _context2.next = 10;
            return button.invoke('onTouchMove')(touchMoveEvent);

          case 10:
            expect(onChange).toHaveBeenCalledWith(20);

          case 11:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  test('should not emit change event when using readonly prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var onChange, touchStartEvent, touchMoveEvent, button;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            mockRect(false);
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onChange: onChange,
              value: 0,
              readonly: true
            }));
            touchStartEvent = {
              touches: [{
                clientX: 0,
                clientY: 0
              }]
            };
            touchMoveEvent = {
              touches: [{
                clientX: 20,
                clientY: 0
              }]
            };
            button = wrapper.find('[role="slider"]');
            _context3.next = 8;
            return button.invoke('onTouchStart')(touchStartEvent);

          case 8:
            _context3.next = 10;
            return button.invoke('onTouchMove')(touchMoveEvent);

          case 10:
            expect(onChange).not.toHaveBeenCalled();

          case 11:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  test('should not emit change event when using disabled prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var onChange, touchStartEvent, touchMoveEvent, button;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            mockRect(false);
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onChange: onChange,
              value: 0,
              disabled: true
            }));
            touchStartEvent = {
              touches: [{
                clientX: 0,
                clientY: 0
              }]
            };
            touchMoveEvent = {
              touches: [{
                clientX: 20,
                clientY: 0
              }]
            };
            button = wrapper.find('[role="slider"]');
            _context4.next = 8;
            return button.invoke('onTouchStart')(touchStartEvent);

          case 8:
            _context4.next = 10;
            return button.invoke('onTouchMove')(touchMoveEvent);

          case 10:
            expect(onChange).not.toHaveBeenCalled();

          case 11:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  test('should not emit change event when using reverse prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    var onChange, touchStartEvent, touchMoveEvent, button;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            mockRect(false);
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onChange: onChange,
              value: 0,
              reverse: true
            }));
            touchStartEvent = {
              touches: [{
                clientX: 100,
                clientY: 0
              }]
            };
            touchMoveEvent = {
              touches: [{
                clientX: 80,
                clientY: 0
              }]
            };
            button = wrapper.find('[role="slider"]');
            _context5.next = 8;
            return button.invoke('onTouchStart')(touchStartEvent);

          case 8:
            _context5.next = 10;
            return button.invoke('onTouchMove')(touchMoveEvent);

          case 10:
            expect(onChange).toHaveBeenCalledWith(20);

          case 11:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  test('should emit onChangeAfter event', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var onChangeAfter, touchStartEvent, touchMoveEvent, button;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            mockRect(false);
            onChangeAfter = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onChangeAfter: onChangeAfter,
              value: 0
            }));
            touchStartEvent = {
              touches: [{
                clientX: 0,
                clientY: 0
              }]
            };
            touchMoveEvent = {
              touches: [{
                clientX: 20,
                clientY: 0
              }]
            };
            button = wrapper.find('[role="slider"]');
            _context6.next = 8;
            return button.invoke('onTouchStart')(touchStartEvent);

          case 8:
            _context6.next = 10;
            return button.invoke('onTouchMove')(touchMoveEvent);

          case 10:
            _context6.next = 12;
            return button.invoke('onTouchEnd')({});

          case 12:
            expect(onChangeAfter).toHaveBeenCalledWith(20);

          case 13:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  test('should emit onDragStart event', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    var onDragStart, touchStartEvent, touchMoveEvent, button;
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            mockRect(false);
            onDragStart = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onDragStart: onDragStart,
              value: 0
            }));
            touchStartEvent = {
              touches: [{
                clientX: 0,
                clientY: 0
              }]
            };
            touchMoveEvent = {
              touches: [{
                clientX: 20,
                clientY: 0
              }]
            };
            button = wrapper.find('[role="slider"]');
            _context7.next = 8;
            return button.invoke('onTouchStart')(touchStartEvent);

          case 8:
            _context7.next = 10;
            return button.invoke('onTouchMove')(touchMoveEvent);

          case 10:
            expect(onDragStart).toHaveBeenCalledWith(touchMoveEvent, 0);

          case 11:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  test('should emit onDragEnd event', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    var onDragEnd, touchStartEvent, touchMoveEvent, button;
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            mockRect(false);
            onDragEnd = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onDragEnd: onDragEnd,
              value: 0
            }));
            touchStartEvent = {
              touches: [{
                clientX: 0,
                clientY: 0
              }]
            };
            touchMoveEvent = {
              touches: [{
                clientX: 20,
                clientY: 0
              }]
            };
            button = wrapper.find('[role="slider"]');
            _context8.next = 8;
            return button.invoke('onTouchStart')(touchStartEvent);

          case 8:
            _context8.next = 10;
            return button.invoke('onTouchMove')(touchMoveEvent);

          case 10:
            _context8.next = 12;
            return button.invoke('onTouchEnd')(touchMoveEvent);

          case 12:
            expect(onDragEnd).toHaveBeenCalledWith(touchMoveEvent, 20);

          case 13:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  test('should emit click event after clicking vertical slider', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    var onChangeAfter;
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            mockRect(true);
            onChangeAfter = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              onChangeAfter: onChangeAfter,
              value: 0,
              vertical: true
            }));
            _context9.next = 5;
            return wrapper.find('.rc-slider').simulate('click', {
              clientX: 0,
              clientY: 20
            });

          case 5:
            expect(onChangeAfter).toHaveBeenCalledWith(20);

          case 6:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('click when use min prop and rang mode ', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
    var onChangeAfter;
    return _regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            mockRect(false);
            onChangeAfter = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              range: true,
              min: 10,
              value: [20, 80],
              onChangeAfter: onChangeAfter
            }));
            _context10.next = 5;
            return wrapper.find('.rc-slider').simulate('click', {
              clientX: 30,
              clientY: 0
            });

          case 5:
            expect(onChangeAfter).toHaveBeenCalledWith([37, 80]);

          case 6:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('click when using min prop and rang prop ', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
    var onChangeAfter;
    return _regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            mockRect(true);
            onChangeAfter = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              range: true,
              min: 10,
              value: [20, 80],
              onChangeAfter: onChangeAfter,
              vertical: true
            }));
            _context11.next = 5;
            return wrapper.find('.rc-slider').simulate('click', {
              clientY: 30,
              clientX: 0
            });

          case 5:
            expect(onChangeAfter).toHaveBeenCalledWith([37, 80]);

          case 6:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
  it('click when using min prop, rang prop and reverse prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee12() {
    var onChangeAfter;
    return _regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            mockRect(true);
            onChangeAfter = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              range: true,
              min: 10,
              value: [20, 80],
              onChangeAfter: onChangeAfter,
              vertical: true,
              reverse: true
            }));
            _context12.next = 5;
            return wrapper.find('.rc-slider').simulate('click', {
              clientY: 30,
              clientX: 0
            });

          case 5:
            expect(onChangeAfter).toHaveBeenCalledWith([20, 73]);

          case 6:
          case "end":
            return _context12.stop();
        }
      }
    }, _callee12);
  })));
  it('click when using min prop and reverse prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee13() {
    var onChangeAfter;
    return _regeneratorRuntime.wrap(function _callee13$(_context13) {
      while (1) {
        switch (_context13.prev = _context13.next) {
          case 0:
            mockRect(false);
            onChangeAfter = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Slider, {
              range: true,
              min: 10,
              value: [80, 20],
              onChangeAfter: onChangeAfter,
              reverse: true
            }));
            _context13.next = 5;
            return wrapper.find('.rc-slider').simulate('click', {
              clientX: 30,
              clientY: 0
            });

          case 5:
            expect(onChangeAfter).toHaveBeenCalledWith([73, 80]);

          case 6:
          case "end":
            return _context13.stop();
        }
      }
    }, _callee13);
  })));
});