import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount, shallow } from 'enzyme';
import { sleep } from '../../../tests/utils';
import Icon from '../../icon';
import BaseToast from '../Toast';
import Toast from '..';
describe('Toast', function () {
  afterEach(function () {
    jest.restoreAllMocks();
  });
  it('toast disappeared after duration', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var handleClose;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            handleClose = jest.fn();
            Toast({
              duration: 10,
              onClose: handleClose
            });
            expect(handleClose).toHaveBeenCalledTimes(0);
            _context.next = 5;
            return sleep(50);

          case 5:
            expect(handleClose).toHaveBeenCalledTimes(1);

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should change overlay style after using overlay-style prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var wrapper;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(BaseToast, {
              visible: true,
              overlay: true,
              overlayStyle: {
                background: 'red'
              }
            }));
            _context2.next = 3;
            return sleep();

          case 3:
            expect(wrapper.find('.rc-overlay').getDOMNode().style.background).toEqual('red');

          case 4:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should emit close event when using closeOnClick prop and clicked', function () {
    var onClose = jest.fn();
    var wrapper = shallow( /*#__PURE__*/React.createElement(BaseToast, {
      visible: true,
      closeOnClick: true,
      onClose: onClose
    }));
    wrapper.find('.rc-toast').simulate('click');
    expect(onClose).toHaveBeenCalledTimes(1);
  });
  it('show loading toast', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var wrapper;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(BaseToast, {
              className: "loading-toast"
            }));
            _context3.next = 3;
            return sleep(3000);

          case 3:
            expect(wrapper.find('.loading-toast').exists()).toBeTruthy();

          case 4:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render correctly when icon prop is string', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var wrapper;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(BaseToast, {
              icon: "start-o"
            }));
            _context4.next = 3;
            return sleep(10);

          case 3:
            expect(wrapper.find('.rc-icon-star-o')).toBeTruthy();

          case 4:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render correctly when icon prop is jsx', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    var wrapper;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(BaseToast, {
              icon: /*#__PURE__*/React.createElement(Icon, {
                name: "shop-o"
              })
            }));
            _context5.next = 3;
            return sleep(10);

          case 3:
            expect(wrapper.find('.rc-icon-shop-o')).toBeTruthy();

          case 4:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('icon-prefix prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var toast;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            toast = Toast({
              icon: 'star-o',
              iconPrefix: 'my-icon'
            });
            _context6.next = 3;
            return sleep(10);

          case 3:
            expect(document.querySelector('.my-icon.my-icon-star-o')).toBeTruthy();
            toast.clear();

          case 5:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('clear multiple toast', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            Toast.allowMultiple(true);
            Toast.info({
              message: '多个提示1'
            });
            _context7.next = 4;
            return sleep(20);

          case 4:
            Toast.info({
              message: '多个提示2'
            });
            _context7.next = 7;
            return sleep(20);

          case 7:
            expect(document.body.querySelectorAll('.toast-contanier').length).toEqual(2);
            jest.useFakeTimers();
            Toast.clear();
            jest.runAllTimers();
            expect(document.body.querySelectorAll('.toast-contanier').length).toEqual(0);

          case 12:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('set default options', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            Toast.setDefaultOptions({
              className: 'my-toast'
            });
            Toast.info({
              message: '提示内容1'
            });
            _context8.next = 4;
            return sleep(20);

          case 4:
            expect(document.querySelector('.my-toast')).toBeTruthy();
            jest.useFakeTimers();
            Toast.clear();
            jest.runAllTimers();
            Toast.resetDefaultOptions();
            Toast.info({
              message: '提示内容2'
            });
            _context8.next = 12;
            return sleep(20);

          case 12:
            expect(document.querySelector('.my-toast')).toBeFalsy();
            jest.useFakeTimers();
            Toast.clear();
            jest.runAllTimers();

          case 16:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('set default options by type', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    var className;
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            className = 'my-toast';
            Toast.setDefaultOptions('loading', {
              className: className
            });
            Toast.loading('');
            _context9.next = 5;
            return sleep(2100);

          case 5:
            expect(document.querySelector('.my-toast')).toBeTruthy();
            jest.useFakeTimers();
            Toast.clear();
            jest.runAllTimers();
            Toast.success('');
            _context9.next = 12;
            return sleep(2100);

          case 12:
            expect(document.querySelector('.my-toast')).toBeFalsy();
            Toast.resetDefaultOptions('loading');
            Toast.loading('');
            expect(document.querySelector('.my-toast')).toBeFalsy();

          case 16:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('toast duration is zero', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
    var onClose;
    return _regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            Toast.allowMultiple(true);
            onClose = jest.fn();
            Toast({
              duration: 0,
              onClose: onClose
            });
            _context10.next = 5;
            return sleep(2100);

          case 5:
            expect(onClose).toHaveBeenCalledTimes(0);
            Toast.allowMultiple(false);

          case 7:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('should trigger onClosed callback after closed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
    var toast;
    return _regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            toast = Toast({
              forbidClick: true
            });
            _context11.next = 3;
            return sleep();

          case 3:
            toast.clear();

          case 4:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
  it('should register component to teleport', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee12() {
    var el;
    return _regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            el = document.createElement('div');
            el.className = 'el-teleport';
            document.body.appendChild(el);
            Toast({
              message: 'hello,world',
              teleport: el
            });
            _context12.next = 6;
            return sleep(10);

          case 6:
            expect(document.querySelector('.el-teleport').querySelector('.rc-toast--info')).toBeTruthy();

          case 7:
          case "end":
            return _context12.stop();
        }
      }
    }, _callee12);
  })));
});